@@ -28,7 +28,7 @@ class DiscreteEnv(gym.Env):
             Xs=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Xa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Y=np.random.binomial(1, 0.05, self.size)))
-    self.model = LogisticRegression().fit(self.df[["Xs", "Xa"]], np.ravel(self.df[["Y"]]))
+    self.model = LogisticRegression().fit(self.df[["Xs", "Xa"]], np.ravel(self.df[["Y"]].astype(int)))
 
     #extract theta parameters from the fitted logistic
 
@@ -100,7 +100,7 @@ class DiscreteEnv(gym.Env):
 
     df_new = pd.DataFrame(data, columns=['Xs', 'Xa', 'Y']) 
 
-    model1 = LogisticRegression().fit(df_new[["Xs", "Xa"]], np.ravel(df_new[["Y"]]))
+    model1 = LogisticRegression().fit(df_new[["Xs", "Xa"]], np.ravel(df_new[["Y"]].astype(int)))
 
     #extract theta parameters from the fitted logistic
     thetas1 = np.array([model1.coef_[0,0] , model1.coef_[0,1], model1.intercept_[0]])
